@@ -2,7 +2,7 @@
 use strict;
 use warnings;
 
-use if $ENV{USER} eq 'gene', lib => map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util);
+use if $ENV{USER} eq 'gene', lib => map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util MIDI-RtMidi-ScorePlayer);
 
 use MIDI::RtMidi::ScorePlayer ();
 use MIDI::Util qw( setup_score set_chan_patch );
@@ -12,7 +12,7 @@ my $score = setup_score( bpm => 120 );
 
 my %common = ( score => $score );
 
-MIDI::RtMidi::FFI::ScorePlayer->new(
+MIDI::RtMidi::ScorePlayer->new(
   score    => $score,
   parts    => [ \&treble, \&bass ],
   common   => \%common,
